@@ -1,6 +1,6 @@
 context("wdpa_read")
 
-test_that("wdpa_read (without point data)", {
+test_that("without point data", {
   skip_on_cran()
   skip_if_not(curl::has_internet())
   skip_on_github_workflow("Windows")
@@ -19,7 +19,7 @@ test_that("wdpa_read (without point data)", {
                   names(x)))
 })
 
-test_that("wdpa_read (with point data)", {
+test_that("with point data", {
   skip_on_cran()
   skip_if_not(curl::has_internet())
   skip_on_github_workflow("Windows")
@@ -41,3 +41,24 @@ test_that("wdpa_read (with point data)", {
   expect_gt(sum(is_point), 0)
   expect_gt(sum(!is_point), 0)
 })
+
+test_that("global data", {
+  skip_on_cran()
+  skip_if_not(curl::has_internet())
+  skip_if_not_installed("pingr")
+  skip_on_github_workflow("Windows")
+  skip_if(
+    (mean(pingr::ping("www.google.com", count = 10)) > 10) &&
+    !identical(Sys.getenv("CI"), "true"))
+  # download data
+  url <- suppressWarnings(wdpa_url("global", wait = TRUE))
+  path <- file.path(tempdir(), "WDPA_WDOECM_Dec2020_Public.gdb.zip")
+  curl::curl_download(url, path)
+  # import data
+  x <- suppressWarnings(wdpa_read(path, n = 5))
+  # tests
+  expect_is(x, "sf")
+  expect_true(nrow(x) > 0)
+  expect_true(all(c("ISO3", "STATUS", "DESIG_ENG", "REP_AREA", "MARINE") %in%
+                  names(x)))
+})
